module GranPulse
  class ApplicationController < ActionController::Base
    protect_from_forgery with: :exception

    def index
      result = []
      GranPulse.checks.each do |check|
        case check
        when 'database'
          result << GranPulse::Database.new.perform
        when 'cache'
          result << GranPulse::Cache.new.perform
        when 'url'
          GranPulse.url_checks.each do |url_check|
            result << GranPulse::Url.new.perform(url_check)
          end
        end
      end
      
      errors = result.select{ |r| r.healthy == false }

      if errors.empty?
        respond_to do |format|
          format.html { render :text => GranPulse.healthy, :content_type => 'text/plain' }
          format.json { render :json => { :healthy => true, :checks => result }}
        end
      else
        respond_to do |format|
          format.html { render :text => errors, :content_type => 'text/plain' }
          format.json { render :json => { :healthy => false, :checks => result }}
        end
      end
    end
  end
end
